==> bitbucket-api-5.14.1-sources.jar: com/atlassian/bitbucket/event/permission/GlobalPermissionModificationRequestedEvent.java <==
package com.atlassian.bitbucket.event.permission;

import com.atlassian.bitbucket.event.CancelableEvent;
import com.atlassian.bitbucket.event.annotation.TransactionAware;
import com.atlassian.bitbucket.i18n.KeyedMessage;
import com.atlassian.bitbucket.permission.Permission;
import com.atlassian.bitbucket.user.ApplicationUser;
import com.atlassian.bitbucket.util.CancelState;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import static com.google.common.base.Preconditions.checkNotNull;

/**
 * This event is raised before a user or group's global permission is modified. This event is synchronous,
 * allowing listeners to perform operations in the same database transaction where the permission is modified.
 * <p>
 * This event is {@link CancelableEvent cancelable}. A listener may prevent the permission
 * from being modified by {@link #cancel(KeyedMessage) canceling} this event.
 * Throwing an exception <i>will not</i> prevent the permission from being modified;
 * the exception will be logged and ignored.
 */
@TransactionAware(value = TransactionAware.When.IMMEDIATE) // Override PermissionEvent
public class GlobalPermissionModificationRequestedEvent extends AbstractGlobalPermissionModificationEvent
        implements PermissionModificationRequestedEvent {

    private final CancelState cancelState;

    public GlobalPermissionModificationRequestedEvent(@Nonnull Object source,
                                                      @Nonnull Permission oldValue, @Nonnull Permission newValue,
                                                      @Nullable String affectedGroup, @Nullable ApplicationUser affectedUser,
                                                      @Nonnull CancelState cancelState) {
        super(source, oldValue, newValue, affectedGroup, affectedUser);

        this.cancelState = checkNotNull(cancelState, "cancelState");
    }

    @Override
    public void cancel(@Nonnull KeyedMessage message) {
        cancelState.cancel(message);
    }

    @Override
    public boolean isCanceled() {
        return cancelState.isCanceled();
    }

}

==> bitbucket-api-8.9.0-sources.jar: com/atlassian/bitbucket/event/permission/GlobalPermissionModificationRequestedEvent.java <==
package com.atlassian.bitbucket.event.permission;

import com.atlassian.audit.entity.CoverageLevel;
import com.atlassian.bitbucket.event.CancelableEvent;
import com.atlassian.bitbucket.event.annotation.TransactionAware;
import com.atlassian.bitbucket.i18n.KeyedMessage;
import com.atlassian.bitbucket.permission.Permission;
import com.atlassian.bitbucket.user.ApplicationUser;
import com.atlassian.bitbucket.util.CancelState;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import static java.util.Objects.requireNonNull;

/**
 * This event is raised before a user or group's global permission is modified. This event is synchronous,
 * allowing listeners to perform operations in the same database transaction where the permission is modified.
 * <p>
 * This event is {@link CancelableEvent cancelable}. A listener may prevent the permission
 * from being modified by {@link #cancel(KeyedMessage) canceling} this event.
 * Throwing an exception <i>will not</i> prevent the permission from being modified;
 * the exception will be logged and ignored.
 * <p>
 * This event is internally audited with {@link CoverageLevel#BASE} level.
 */
@TransactionAware(value = TransactionAware.When.IMMEDIATE) // Override PermissionEvent
public class GlobalPermissionModificationRequestedEvent extends AbstractGlobalPermissionModificationEvent
        implements PermissionModificationRequestedEvent {

    private final CancelState cancelState;

    public GlobalPermissionModificationRequestedEvent(@Nonnull Object source,
                                                      @Nonnull Permission oldValue, @Nonnull Permission newValue,
                                                      @Nullable String affectedGroup, @Nullable ApplicationUser affectedUser,
                                                      @Nonnull CancelState cancelState) {
        super(source, oldValue, newValue, affectedGroup, affectedUser);

        this.cancelState = requireNonNull(cancelState, "cancelState");
    }

    @Override
    public void cancel(@Nonnull KeyedMessage message) {
        cancelState.cancel(message);
    }

    @Override
    public boolean isCanceled() {
        return cancelState.isCanceled();
    }

}
